
[![CircleCI](https://circleci.com/gh/duckietown/duckietown-world.svg?style=shield)](https://circleci.com/gh/duckietown/duckietown-world)


# Duckietown World


This package provides functions to reason about the state of the world in Duckietown.

## Installation from source

    $ pip install -r requirements.txt
    $ python setup.py develop --no-deps
    
    

## Demo

Run this:

    $ make tests-clean tests
    
and look at the figures generated in `out-comptests/`.


You can also see these artifacts generated by CI:
 
<https://circleci.com/gh/duckietown/duckietown-world/306#artifacts/containers/0>
